@@ -1,5 +1,5 @@
 from flagbase.client import FlagbaseClient
 from flagbase.config import Config, Mode
-from flagbase.events import EventType
+from flagbase.types import EventType
 from flagbase.identity import Identity
 from flagbase.version import __version__
\ No newline at end of file
