@@ -1,4 +1,7 @@
 from enum import Enum
+from typing import List
+
+from flagbase.types import EventType
 
 class Mode(Enum):
     HYBRID = "hybrid"
@@ -10,8 +13,9 @@ class Config:
         self, 
         server_key: str, 
         mode: Mode = Mode.POLLING, 
-        polling_service_url: str ="https://poller.core.flagbase.com", 
-        polling_interval_ms: int =10000):
+        polling_service_url: str = "https://poller.core.flagbase.com", 
+        polling_interval_ms: int = 10000,
+        log_events: List[EventType] = [EventType.LOG_CRITICAL, EventType.LOG_ERROR]):
 
         if server_key is None:
             raise ValueError("Missing Server SDK Key when constructing the client.")
@@ -20,6 +24,7 @@ class Config:
         self.mode = mode
         self.polling_service_url = polling_service_url
         self.polling_interval_ms = polling_interval_ms
+        self.log_events = log_events
 
     def get_server_key(self) -> str:
         return self.server_key
@@ -32,3 +37,6 @@ class Config:
 
     def get_polling_interval_ms(self) -> int:
         return self.polling_interval_ms
+
+    def get_log_events(self) -> List[EventType]:
+        return self.log_events
\ No newline at end of file
